"use strict";(self.rspackChunk_JUPYTERLAB_CORE_OUTPUT=self.rspackChunk_JUPYTERLAB_CORE_OUTPUT||[]).push([[2672],{34403(e,a,r){r.d(a,{diagram:()=>g});var t=r(74571),s=r(74725),n=r(87724),d=r(11150),i={parse:(0,n.K2)(async e=>{let a=await (0,d.qg)("info",e);n.Rm.debug(a)},"parse")},p=(0,n.K2)(()=>"11.15.0","getVersion"),g={parser:i,db:{getVersion:p},renderer:{draw:(0,n.K2)((e,a,r)=>{n.Rm.debug("rendering info diagram\n"+e);let d=(0,t.D)(a);(0,s.a$)(d,100,400,!0),d.append("g").append("text").attr("x",100).attr("y",40).attr("class","version").attr("font-size",32).style("text-anchor","middle").text(`v${r}`)},"draw")}}}}]);